@@ -1,11 +1,12 @@
 """
-$description Global live streaming and video on-demand hosting platform.
+$description Global live-streaming and video on-demand hosting platform.
 $url ott.streann.com
 $url centroecuador.ec
 $url columnaestilos.com
 $url evtv.online/noticias-de-venezuela
 $url telecuracao.com
 $type live, vod
+$metadata title
 """
 
 import base64
@@ -15,17 +16,18 @@ import re
 import time
 from urllib.parse import urlparse
 
-from streamlink.plugin import Plugin, PluginArgument, PluginArguments, pluginmatcher
+from streamlink.plugin import Plugin, pluginargument, pluginmatcher
 from streamlink.plugin.api import validate
 from streamlink.stream.hls import HLSStream
 from streamlink.utils.crypto import decrypt_openssl
 from streamlink.utils.parse import parse_qsd
 
+
 log = logging.getLogger(__name__)
 
 
 @pluginmatcher(re.compile(
-    r"https?://ott\.streann\.com/s(?:treaming|-secure)/player\.html"
+    r"https?://ott\.streann\.com/s(?:treaming|-secure)/player\.html",
 ))
 @pluginmatcher(re.compile(r"""
     https?://(?:www\.)?(?:
@@ -40,26 +42,22 @@ log = logging.getLogger(__name__)
         telecuracao\.com
     )
 """, re.VERBOSE))
+@pluginargument(
+    "url",
+    metavar="URL",
+    help="Source URL where the iframe is located, only required for direct URLs of ott.streann.com",
+)
 class Streann(Plugin):
-    arguments = PluginArguments(
-        PluginArgument(
-            "url",
-            type=str,
-            metavar="URL",
-            help="""
-            Source URL where the iframe is located,
-            only required for direct URLs of `ott.streann.com`
-            """
-        )
-    )
-
     base_url = "https://ott.streann.com"
     get_time_url = base_url + "/web/services/public/get-server-time"
     token_url = base_url + "/loadbalancer/services/web-players/{playerId}/token/{type}/{dataId}/{deviceId}"
-    stream_url = base_url + "/loadbalancer/services/web-players/{type}s-reseller-secure/{dataId}/{playerId}" \
-                            "/{token}/{resellerId}/playlist.m3u8?date={time}&device-type=web&device-name=web" \
-                            "&device-os=web&device-id={deviceId}"
-    passphrase_re = re.compile(r'''CryptoJS\.AES\.decrypt\(.*?,\s*(['"])(?P<passphrase>(?:(?!\1).)*)\1\s*?\);''')
+    stream_url = (
+        base_url
+        + "/loadbalancer/services/web-players/{type}s-reseller-secure/{dataId}/{playerId}"
+        + "/{token}/{resellerId}/playlist.m3u8?date={time}&device-type=web&device-name=web"
+        + "&device-os=web&device-id={deviceId}"
+    )
+    passphrase_re = re.compile(r"""CryptoJS\.AES\.decrypt\(.*?,\s*(['"])(?P<passphrase>(?:(?!\1).)*)\1\s*?\);""")
 
     _device_id = None
     _domain = None
@@ -95,13 +93,13 @@ class Streann(Plugin):
         headers = {
             "Referer": self.url,
             "X-Requested-With": "XMLHttpRequest",
-            "Content-Type": "application/x-www-form-urlencoded"
+            "Content-Type": "application/x-www-form-urlencoded",
         }
 
         res = self.session.http.post(
             self.token_url.format(deviceId=self.device_id, **config),
             data=pdata,
-            headers=headers
+            headers=headers,
         )
 
         if res.status_code == 204:
@@ -128,7 +126,7 @@ class Streann(Plugin):
             iframes = self.session.http.get(self.url, schema=validate.Schema(
                 validate.parse_html(),
                 validate.xml_findall(".//iframe[@src]"),
-                validate.filter(lambda elem: urlparse(elem.attrib.get("src")).netloc == "ott.streann.com")
+                validate.filter(lambda elem: urlparse(elem.attrib.get("src")).netloc == "ott.streann.com"),
             ))
             if not iframes:
                 log.error("Could not find 'ott.streann.com' iframe")
