@@ -12,19 +12,15 @@ from streamlink.stream.hls import HLSStream
 
 
 @pluginmatcher(re.compile(
-    r"https?://(?:www\.)?tv360\.com\.tr/canli-yayin"
+    r"https?://(?:www\.)?tv360\.com\.tr/canli-yayin",
 ))
 class TV360(Plugin):
-    hls_re = re.compile(r'''src="(http.*m3u8)"''')
-
-    hls_schema = validate.Schema(
-        validate.transform(hls_re.search),
-        validate.any(None, validate.all(validate.get(1), validate.url()))
-    )
-
     def _get_streams(self):
-        hls_url = self.session.http.get(self.url, schema=self.hls_schema)
-
+        hls_url = self.session.http.get(self.url, schema=validate.Schema(
+            validate.parse_html(),
+            validate.xml_xpath_string(".//video/source[@src][@type='application/x-mpegURL'][1]/@src"),
+            validate.none_or_all(validate.url()),
+        ))
         if hls_url:
             return HLSStream.parse_variant_playlist(self.session, hls_url)
 
